findSystemLocale function

Future<String> findSystemLocale()

Find the system locale, accessed via the appropriate system APIs, and set it as the default for internationalization operations in the Intl.systemLocale variable.

Implementation

Future<String> findSystemLocale() {
  throw UnsupportedError(
    'intl.findSystemLocale is not implemented on this platform.',
  );
}